# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'resources/form/integracao.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormIntegracao(object):
    def setupUi(self, FormIntegracao):
        FormIntegracao.setObjectName("FormIntegracao")
        FormIntegracao.resize(419, 254)
        self.verticalLayout = QtWidgets.QVBoxLayout(FormIntegracao)
        self.verticalLayout.setObjectName("verticalLayout")
        self.labelDescricao = QtWidgets.QLabel(FormIntegracao)
        self.labelDescricao.setWordWrap(True)
        self.labelDescricao.setObjectName("labelDescricao")
        self.verticalLayout.addWidget(self.labelDescricao)
        self.groupBox = QtWidgets.QGroupBox(FormIntegracao)
        self.groupBox.setTitle("")
        self.groupBox.setFlat(False)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.checkTraceback = QtWidgets.QCheckBox(self.groupBox)
        self.checkTraceback.setObjectName("checkTraceback")
        self.verticalLayout_2.addWidget(self.checkTraceback)
        self.checkVerboso = QtWidgets.QCheckBox(self.groupBox)
        self.checkVerboso.setObjectName("checkVerboso")
        self.verticalLayout_2.addWidget(self.checkVerboso)
        self.checkDataNoLog = QtWidgets.QCheckBox(self.groupBox)
        self.checkDataNoLog.setObjectName("checkDataNoLog")
        self.verticalLayout_2.addWidget(self.checkDataNoLog)
        self.checkPararCasoErros = QtWidgets.QCheckBox(self.groupBox)
        self.checkPararCasoErros.setObjectName("checkPararCasoErros")
        self.verticalLayout_2.addWidget(self.checkPararCasoErros)
        self.verticalLayout.addWidget(self.groupBox)
        self.buttonExecutar = QtWidgets.QPushButton(FormIntegracao)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.buttonExecutar.sizePolicy().hasHeightForWidth())
        self.buttonExecutar.setSizePolicy(sizePolicy)
        self.buttonExecutar.setObjectName("buttonExecutar")
        self.verticalLayout.addWidget(self.buttonExecutar)

        self.retranslateUi(FormIntegracao)
        QtCore.QMetaObject.connectSlotsByName(FormIntegracao)

    def retranslateUi(self, FormIntegracao):
        _translate = QtCore.QCoreApplication.translate
        FormIntegracao.setWindowTitle(_translate("FormIntegracao", "Integração"))
        self.labelDescricao.setText(_translate("FormIntegracao", "<html><head/><body><p>Efetua a carga de dados pendentes para as apis.</p></body></html>"))
        self.checkTraceback.setText(_translate("FormIntegracao", "Exibir trace."))
        self.checkVerboso.setText(_translate("FormIntegracao", "Log verboso."))
        self.checkDataNoLog.setText(_translate("FormIntegracao", "Imprimir data no log."))
        self.checkPararCasoErros.setText(_translate("FormIntegracao", "Parar caso ocorra erro."))
        self.buttonExecutar.setText(_translate("FormIntegracao", "▶   Executar"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormIntegracao = QtWidgets.QWidget()
    ui = Ui_FormIntegracao()
    ui.setupUi(FormIntegracao)
    FormIntegracao.show()
    sys.exit(app.exec_())
