# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'resources/form/conf_carga_continua.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormCargaContinua(object):
    def setupUi(self, FormCargaContinua):
        FormCargaContinua.setObjectName("FormCargaContinua")
        FormCargaContinua.resize(366, 206)
        FormCargaContinua.setMinimumSize(QtCore.QSize(366, 206))
        FormCargaContinua.setMaximumSize(QtCore.QSize(366, 206))
        self.verticalLayout = QtWidgets.QVBoxLayout(FormCargaContinua)
        self.verticalLayout.setObjectName("verticalLayout")
        self.labelDescricao = QtWidgets.QLabel(FormCargaContinua)
        self.labelDescricao.setObjectName("labelDescricao")
        self.verticalLayout.addWidget(self.labelDescricao)
        self.groupAgendamento = QtWidgets.QGroupBox(FormCargaContinua)
        self.groupAgendamento.setTitle("")
        self.groupAgendamento.setObjectName("groupAgendamento")
        self.formLayout = QtWidgets.QFormLayout(self.groupAgendamento)
        self.formLayout.setObjectName("formLayout")
        self.labelIntervalo = QtWidgets.QLabel(self.groupAgendamento)
        self.labelIntervalo.setObjectName("labelIntervalo")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.labelIntervalo)
        self.spinIntervalo = QtWidgets.QSpinBox(self.groupAgendamento)
        self.spinIntervalo.setMaximum(43200)
        self.spinIntervalo.setProperty("value", 5)
        self.spinIntervalo.setObjectName("spinIntervalo")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.spinIntervalo)
        self.labelParametros = QtWidgets.QLabel(self.groupAgendamento)
        self.labelParametros.setObjectName("labelParametros")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.labelParametros)
        self.labelParametrosValor = QtWidgets.QLabel(self.groupAgendamento)
        self.labelParametrosValor.setObjectName("labelParametrosValor")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.labelParametrosValor)
        self.verticalLayout.addWidget(self.groupAgendamento)
        self.layoutButtons = QtWidgets.QHBoxLayout()
        self.layoutButtons.setObjectName("layoutButtons")
        self.btnAgendar = QtWidgets.QPushButton(FormCargaContinua)
        self.btnAgendar.setObjectName("btnAgendar")
        self.layoutButtons.addWidget(self.btnAgendar)
        self.btnCancelar = QtWidgets.QPushButton(FormCargaContinua)
        self.btnCancelar.setObjectName("btnCancelar")
        self.layoutButtons.addWidget(self.btnCancelar)
        self.verticalLayout.addLayout(self.layoutButtons)
        self.labelStatus = QtWidgets.QLabel(FormCargaContinua)
        self.labelStatus.setObjectName("labelStatus")
        self.verticalLayout.addWidget(self.labelStatus)

        self.retranslateUi(FormCargaContinua)
        QtCore.QMetaObject.connectSlotsByName(FormCargaContinua)

    def retranslateUi(self, FormCargaContinua):
        _translate = QtCore.QCoreApplication.translate
        FormCargaContinua.setWindowTitle(_translate("FormCargaContinua", "Agendamento Carga Contínua"))
        self.labelDescricao.setText(_translate("FormCargaContinua", "<html><head/><body><p>Agende a carga de dados para a API.</p></body></html>"))
        self.labelIntervalo.setText(_translate("FormCargaContinua", "Intervalo (minutos):"))
        self.labelParametros.setText(_translate("FormCargaContinua", "Parâmetros:"))
        self.labelParametrosValor.setText(_translate("FormCargaContinua", "(Nenhum)"))
        self.btnAgendar.setText(_translate("FormCargaContinua", "📅 Agendar"))
        self.btnCancelar.setText(_translate("FormCargaContinua", "Cancelar Agendamento"))
        self.labelStatus.setText(_translate("FormCargaContinua", "Status atual: Não agendado"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormCargaContinua = QtWidgets.QWidget()
    ui = Ui_FormCargaContinua()
    ui.setupUi(FormCargaContinua)
    FormCargaContinua.show()
    sys.exit(app.exec_())
