from nsj_integracao_api_client.service.cfg.base import _entidades_base

_entidades_meurh_trab = [
    *_entidades_base,
    'persona.condicoesambientestrabalho',
    'persona.membroscipa',
    'persona.ambientes',
    'persona.reajustessindicatos',
    'persona.reajustestrabalhadores',
    'persona.tarifasconcessionariasvts',
    'persona.tarifasconcessionariasvtstrabalhadores',
    'persona.tiposanexos',
    'persona.historicosadiantamentosavulsos',
    'persona.convocacoestrabalhadores',
    'persona.configuracoesordemcalculomovimentos',
    'persona.dispensavalestransportestrabalhadores',
    'persona.funcoes',
    'persona.medicos',
    'persona.rubricasponto',
    'persona.configuracoesordemcalculomovimentosponto',
    'persona.historicos',
    'persona.tiposhistoricos',
    'persona.eventos',
    'persona.dependentestrabalhadores',
    'financas.bancos',
    'persona.beneficios',
    'persona.concessionariasvts',
    'persona.emprestimostrabalhadores',
    'persona.faixas',
    'persona.compromissostrabalhadores',
    'persona.tiposdocumentoscolaboradores',
    'persona.admissoespreliminares',
    'persona.avisosferiastrabalhadores',
    'persona.cargos',
    'persona.tiposfuncionarios',
    'persona.processos',
    'persona.niveiscargos',
    'persona.mudancastrabalhadores',
    'persona.jornadas',
    'persona.lotacoes',
    'persona.trabalhadores',
    'persona.documentoscolaboradores',
    'persona.escalasfolgastrabalhadores',
    'persona.faltastrabalhadores',
    'persona.horarios',
    'persona.instituicoes',
    'persona.intervalosjornadas',
    'ns.configuracoes',
    'persona.pendenciaspagamentos',
    'persona.afastamentostrabalhadores',
    'ns.feriados',
    'persona.adiantamentosavulsos',
    'persona.departamentos',
    'persona.horariosespeciais',
    'persona.sindicatos',
    'persona.movimentosponto',
    'persona.beneficiostrabalhadores',
    'persona.movimentos',
    'persona.beneficiostrabalhadoressuspensoesadesoes', # a partir da v2.2501
    'persona.beneficiostrabalhadoresadesoes', # a partir da v2.2501
    'persona.calculostrabalhadores',
]

_entidades_ponto = [
    *_entidades_meurh_trab,
    'ponto.compensacoeslancamentos',
    'ponto.pagamentoslancamentos',
    'ponto.atrasosentradascompensaveistrabalhadores',
    'ponto.saidasantecipadascompensaveistrabalhadores',
    'ponto.regras',
    'ponto.diascompensacoestrabalhadores',
    'ponto.periodossemmarcacoes'
]

_entidades_portal = [
    *_entidades_base,
    'persona.cargos',
    'persona.niveiscargos',
    'persona.trabalhadores',
    'ns.configuracoes',
    'ns.locaisdeuso',
    'persona.afastamentostrabalhadores',
    'persona.departamentos',
]

_entidades_avaliacao = [
    *_entidades_base,
    'persona.cargos',
    'persona.niveiscargos',
    'persona.mudancastrabalhadores',
    'persona.trabalhadores',
    'ns.locaisdeuso',
    'persona.departamentos',
]