# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'resources/form/status.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_StatusForm(object):
    def setupUi(self, StatusForm):
        StatusForm.setObjectName("StatusForm")
        StatusForm.resize(483, 245)
        StatusForm.setMinimumSize(QtCore.QSize(483, 238))
        StatusForm.setMaximumSize(QtCore.QSize(483, 320))
        self.verticalLayout = QtWidgets.QVBoxLayout(StatusForm)
        self.verticalLayout.setObjectName("verticalLayout")
        self.frameStatus = QtWidgets.QFrame(StatusForm)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frameStatus.sizePolicy().hasHeightForWidth())
        self.frameStatus.setSizePolicy(sizePolicy)
        self.frameStatus.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frameStatus.setObjectName("frameStatus")
        self.horizontalLayoutStatus = QtWidgets.QHBoxLayout(self.frameStatus)
        self.horizontalLayoutStatus.setObjectName("horizontalLayoutStatus")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.verticalLayout_2.setContentsMargins(-1, -1, 10, -1)
        self.verticalLayout_2.setSpacing(0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.indicatorStatus = QtWidgets.QLabel(self.frameStatus)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(3)
        sizePolicy.setVerticalStretch(3)
        sizePolicy.setHeightForWidth(self.indicatorStatus.sizePolicy().hasHeightForWidth())
        self.indicatorStatus.setSizePolicy(sizePolicy)
        self.indicatorStatus.setMinimumSize(QtCore.QSize(32, 32))
        self.indicatorStatus.setMaximumSize(QtCore.QSize(32, 32))
        self.indicatorStatus.setTextFormat(QtCore.Qt.AutoText)
        self.indicatorStatus.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.indicatorStatus.setObjectName("indicatorStatus")
        self.verticalLayout_2.addWidget(self.indicatorStatus)
        spacerItem = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem)
        self.horizontalLayoutStatus.addLayout(self.verticalLayout_2)
        self.labelStatus = QtWidgets.QLabel(self.frameStatus)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelStatus.sizePolicy().hasHeightForWidth())
        self.labelStatus.setSizePolicy(sizePolicy)
        self.labelStatus.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.labelStatus.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.labelStatus.setObjectName("labelStatus")
        self.horizontalLayoutStatus.addWidget(self.labelStatus)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setSizeConstraint(QtWidgets.QLayout.SetFixedSize)
        self.verticalLayout_3.setSpacing(0)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.btnAtualizar = QtWidgets.QPushButton(self.frameStatus)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnAtualizar.sizePolicy().hasHeightForWidth())
        self.btnAtualizar.setSizePolicy(sizePolicy)
        self.btnAtualizar.setMaximumSize(QtCore.QSize(30, 30))
        self.btnAtualizar.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.btnAtualizar.setDefault(False)
        self.btnAtualizar.setFlat(True)
        self.btnAtualizar.setObjectName("btnAtualizar")
        self.verticalLayout_3.addWidget(self.btnAtualizar)
        spacerItem1 = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem1)
        self.horizontalLayoutStatus.addLayout(self.verticalLayout_3)
        self.verticalLayout.addWidget(self.frameStatus)
        self.groupBoxInfo = QtWidgets.QGroupBox(StatusForm)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBoxInfo.sizePolicy().hasHeightForWidth())
        self.groupBoxInfo.setSizePolicy(sizePolicy)
        self.groupBoxInfo.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBoxInfo.setMaximumSize(QtCore.QSize(16777215, 107))
        self.groupBoxInfo.setObjectName("groupBoxInfo")
        self.gridLayoutInfo = QtWidgets.QGridLayout(self.groupBoxInfo)
        self.gridLayoutInfo.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.gridLayoutInfo.setContentsMargins(9, -1, 9, -1)
        self.gridLayoutInfo.setObjectName("gridLayoutInfo")
        self.labelUltimaIntegracao = QtWidgets.QLabel(self.groupBoxInfo)
        self.labelUltimaIntegracao.setMaximumSize(QtCore.QSize(165, 16777215))
        self.labelUltimaIntegracao.setObjectName("labelUltimaIntegracao")
        self.gridLayoutInfo.addWidget(self.labelUltimaIntegracao, 0, 0, 1, 1)
        self.labelPendentes = QtWidgets.QLabel(self.groupBoxInfo)
        self.labelPendentes.setMaximumSize(QtCore.QSize(165, 16777215))
        self.labelPendentes.setObjectName("labelPendentes")
        self.gridLayoutInfo.addWidget(self.labelPendentes, 2, 0, 1, 1)
        self.valueProximaIntegracao = QtWidgets.QLabel(self.groupBoxInfo)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.valueProximaIntegracao.sizePolicy().hasHeightForWidth())
        self.valueProximaIntegracao.setSizePolicy(sizePolicy)
        self.valueProximaIntegracao.setWordWrap(True)
        self.valueProximaIntegracao.setObjectName("valueProximaIntegracao")
        self.gridLayoutInfo.addWidget(self.valueProximaIntegracao, 1, 1, 1, 1)
        self.labelProximaIntegracao = QtWidgets.QLabel(self.groupBoxInfo)
        self.labelProximaIntegracao.setMaximumSize(QtCore.QSize(165, 16777215))
        self.labelProximaIntegracao.setObjectName("labelProximaIntegracao")
        self.gridLayoutInfo.addWidget(self.labelProximaIntegracao, 1, 0, 1, 1)
        self.valueUltimaIntegracao = QtWidgets.QLabel(self.groupBoxInfo)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.valueUltimaIntegracao.sizePolicy().hasHeightForWidth())
        self.valueUltimaIntegracao.setSizePolicy(sizePolicy)
        self.valueUltimaIntegracao.setObjectName("valueUltimaIntegracao")
        self.gridLayoutInfo.addWidget(self.valueUltimaIntegracao, 0, 1, 1, 1)
        self.valuePendentes = QtWidgets.QLabel(self.groupBoxInfo)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.valuePendentes.sizePolicy().hasHeightForWidth())
        self.valuePendentes.setSizePolicy(sizePolicy)
        self.valuePendentes.setObjectName("valuePendentes")
        self.gridLayoutInfo.addWidget(self.valuePendentes, 2, 1, 1, 1)
        self.verticalLayout.addWidget(self.groupBoxInfo)
        self.horizontalLayoutButtons = QtWidgets.QHBoxLayout()
        self.horizontalLayoutButtons.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.horizontalLayoutButtons.setObjectName("horizontalLayoutButtons")
        self.btnIntegrarManual = QtWidgets.QPushButton(StatusForm)
        self.btnIntegrarManual.setObjectName("btnIntegrarManual")
        self.horizontalLayoutButtons.addWidget(self.btnIntegrarManual)
        self.btnConfig = QtWidgets.QPushButton(StatusForm)
        self.btnConfig.setObjectName("btnConfig")
        self.horizontalLayoutButtons.addWidget(self.btnConfig)
        self.verticalLayout.addLayout(self.horizontalLayoutButtons)

        self.retranslateUi(StatusForm)
        QtCore.QMetaObject.connectSlotsByName(StatusForm)

    def retranslateUi(self, StatusForm):
        _translate = QtCore.QCoreApplication.translate
        StatusForm.setWindowTitle(_translate("StatusForm", "Status da Integração"))
        self.indicatorStatus.setToolTip(_translate("StatusForm", "Verde: Funcionando normalmente, Amarelo: Com problemas, Vermelho: Parado/Falha"))
        self.indicatorStatus.setStyleSheet(_translate("StatusForm", "background-color: green; border-radius: 16px;"))
        self.labelStatus.setText(_translate("StatusForm", "Status do serviço"))
        self.btnAtualizar.setText(_translate("StatusForm", "⟲"))
        self.groupBoxInfo.setTitle(_translate("StatusForm", "Informações"))
        self.labelUltimaIntegracao.setText(_translate("StatusForm", "Última integração:"))
        self.labelPendentes.setText(_translate("StatusForm", "Dados pendentes:"))
        self.valueProximaIntegracao.setText(_translate("StatusForm", "Não informado"))
        self.labelProximaIntegracao.setText(_translate("StatusForm", "Próxima integração:"))
        self.valueUltimaIntegracao.setText(_translate("StatusForm", "Não informado"))
        self.valuePendentes.setText(_translate("StatusForm", "Não informado"))
        self.btnIntegrarManual.setText(_translate("StatusForm", "⚡ Integrar manualmente"))
        self.btnConfig.setText(_translate("StatusForm", "⚙ Configurações"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    StatusForm = QtWidgets.QWidget()
    ui = Ui_StatusForm()
    ui.setupUi(StatusForm)
    StatusForm.show()
    sys.exit(app.exec_())
