# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'resources/form/configuracoes_gerais.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormConfiguracoesGerais(object):
    def setupUi(self, FormConfiguracoesGerais):
        FormConfiguracoesGerais.setObjectName("FormConfiguracoesGerais")
        FormConfiguracoesGerais.resize(351, 223)
        self.verticalLayout = QtWidgets.QVBoxLayout(FormConfiguracoesGerais)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupAgendamento = QtWidgets.QGroupBox(FormConfiguracoesGerais)
        self.groupAgendamento.setTitle("")
        self.groupAgendamento.setObjectName("groupAgendamento")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.groupAgendamento)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.formLayout = QtWidgets.QFormLayout()
        self.formLayout.setObjectName("formLayout")
        self.labelAmbiente = QtWidgets.QLabel(self.groupAgendamento)
        self.labelAmbiente.setObjectName("labelAmbiente")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.labelAmbiente)
        self.comboBox = QtWidgets.QComboBox(self.groupAgendamento)
        self.comboBox.setObjectName("comboBox")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.comboBox)
        self.verticalLayout_3.addLayout(self.formLayout)
        self.checkBox = QtWidgets.QCheckBox(self.groupAgendamento)
        self.checkBox.setObjectName("checkBox")
        self.verticalLayout_3.addWidget(self.checkBox)
        self.formLayout_2 = QtWidgets.QFormLayout()
        self.formLayout_2.setObjectName("formLayout_2")
        self.labelTenantEspelho = QtWidgets.QLabel(self.groupAgendamento)
        self.labelTenantEspelho.setObjectName("labelTenantEspelho")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.labelTenantEspelho)
        self.lineEdit = QtWidgets.QLineEdit(self.groupAgendamento)
        self.lineEdit.setObjectName("lineEdit")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.lineEdit)
        self.verticalLayout_3.addLayout(self.formLayout_2)
        self.verticalLayout.addWidget(self.groupAgendamento)
        self.layoutButtons = QtWidgets.QHBoxLayout()
        self.layoutButtons.setObjectName("layoutButtons")
        self.btnSalvar = QtWidgets.QPushButton(FormConfiguracoesGerais)
        self.btnSalvar.setObjectName("btnSalvar")
        self.layoutButtons.addWidget(self.btnSalvar)
        self.btnCancelar = QtWidgets.QPushButton(FormConfiguracoesGerais)
        self.btnCancelar.setObjectName("btnCancelar")
        self.layoutButtons.addWidget(self.btnCancelar)
        self.verticalLayout.addLayout(self.layoutButtons)

        self.retranslateUi(FormConfiguracoesGerais)
        QtCore.QMetaObject.connectSlotsByName(FormConfiguracoesGerais)

    def retranslateUi(self, FormConfiguracoesGerais):
        _translate = QtCore.QCoreApplication.translate
        FormConfiguracoesGerais.setWindowTitle(_translate("FormConfiguracoesGerais", "Configurações Gerais"))
        self.labelAmbiente.setText(_translate("FormConfiguracoesGerais", "Ambiente:"))
        self.checkBox.setText(_translate("FormConfiguracoesGerais", "Espelhar dados em outro Tenant?"))
        self.labelTenantEspelho.setText(_translate("FormConfiguracoesGerais", "Tenant Espelho:"))
        self.btnSalvar.setText(_translate("FormConfiguracoesGerais", "Salvar"))
        self.btnCancelar.setText(_translate("FormConfiguracoesGerais", "Cancelar"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormConfiguracoesGerais = QtWidgets.QWidget()
    ui = Ui_FormConfiguracoesGerais()
    ui.setupUi(FormConfiguracoesGerais)
    FormConfiguracoesGerais.show()
    sys.exit(app.exec_())
