# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'resources/form/pendencias.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormItensPendentes(object):
    def setupUi(self, FormItensPendentes):
        FormItensPendentes.setObjectName("FormItensPendentes")
        FormItensPendentes.resize(800, 600)
        FormItensPendentes.setMinimumSize(QtCore.QSize(800, 600))
        FormItensPendentes.setMaximumSize(QtCore.QSize(800, 600))
        self.verticalLayout = QtWidgets.QVBoxLayout(FormItensPendentes)
        self.verticalLayout.setObjectName("verticalLayout")
        self.label = QtWidgets.QLabel(FormItensPendentes)
        self.label.setStyleSheet("font-size: 16px; font-weight: bold; margin: 4px;")
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        self.groupItensPendentes = QtWidgets.QGroupBox(FormItensPendentes)
        self.groupItensPendentes.setTitle("")
        self.groupItensPendentes.setFlat(False)
        self.groupItensPendentes.setCheckable(False)
        self.groupItensPendentes.setObjectName("groupItensPendentes")
        self.verticalLayoutGrupos = QtWidgets.QVBoxLayout(self.groupItensPendentes)
        self.verticalLayoutGrupos.setObjectName("verticalLayoutGrupos")
        self.tableItensPendentes = QtWidgets.QTableWidget(self.groupItensPendentes)
        self.tableItensPendentes.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAsNeeded)
        self.tableItensPendentes.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.tableItensPendentes.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectColumns)
        self.tableItensPendentes.setObjectName("tableItensPendentes")
        self.tableItensPendentes.setColumnCount(2)
        self.tableItensPendentes.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tableItensPendentes.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableItensPendentes.setHorizontalHeaderItem(1, item)
        self.verticalLayoutGrupos.addWidget(self.tableItensPendentes)
        self.verticalLayout.addWidget(self.groupItensPendentes)

        self.retranslateUi(FormItensPendentes)
        QtCore.QMetaObject.connectSlotsByName(FormItensPendentes)

    def retranslateUi(self, FormItensPendentes):
        _translate = QtCore.QCoreApplication.translate
        FormItensPendentes.setWindowTitle(_translate("FormItensPendentes", "Integração por APIs"))
        self.label.setText(_translate("FormItensPendentes", "Entidades pendentes"))
        item = self.tableItensPendentes.horizontalHeaderItem(0)
        item.setText(_translate("FormItensPendentes", "Entidade"))
        item = self.tableItensPendentes.horizontalHeaderItem(1)
        item.setText(_translate("FormItensPendentes", "Quantidade"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormItensPendentes = QtWidgets.QWidget()
    ui = Ui_FormItensPendentes()
    ui.setupUi(FormItensPendentes)
    FormItensPendentes.show()
    sys.exit(app.exec_())
