# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'resources/form/log_integridade.ui'
#
# Created by: PyQt5 UI code generator 5.15.6
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormLogIntegridade(object):
    def setupUi(self, FormLogIntegridade):
        FormLogIntegridade.setObjectName("FormLogIntegridade")
        FormLogIntegridade.resize(1200, 720)
        self.verticalLayout = QtWidgets.QVBoxLayout(FormLogIntegridade)
        self.verticalLayout.setObjectName("verticalLayout")
        self.splitter = QtWidgets.QSplitter(FormLogIntegridade)
        self.splitter.setOrientation(QtCore.Qt.Horizontal)
        self.splitter.setObjectName("splitter")
        self.widgetLeft = QtWidgets.QWidget(self.splitter)
        self.widgetLeft.setMaximumSize(QtCore.QSize(220, 16777215))
        self.widgetLeft.setObjectName("widgetLeft")
        self.verticalLayoutLeft = QtWidgets.QVBoxLayout(self.widgetLeft)
        self.verticalLayoutLeft.setContentsMargins(0, 0, 0, 0)
        self.verticalLayoutLeft.setObjectName("verticalLayoutLeft")
        self.labelDia = QtWidgets.QLabel(self.widgetLeft)
        self.labelDia.setObjectName("labelDia")
        self.verticalLayoutLeft.addWidget(self.labelDia)
        self.listDias = QtWidgets.QListWidget(self.widgetLeft)
        self.listDias.setAlternatingRowColors(True)
        self.listDias.setObjectName("listDias")
        self.verticalLayoutLeft.addWidget(self.listDias)
        self.labelExecucao = QtWidgets.QLabel(self.widgetLeft)
        self.labelExecucao.setObjectName("labelExecucao")
        self.verticalLayoutLeft.addWidget(self.labelExecucao)
        self.listExecucoes = QtWidgets.QListWidget(self.widgetLeft)
        self.listExecucoes.setAlternatingRowColors(True)
        self.listExecucoes.setObjectName("listExecucoes")
        self.verticalLayoutLeft.addWidget(self.listExecucoes)
        self.widgetRight = QtWidgets.QWidget(self.splitter)
        self.widgetRight.setObjectName("widgetRight")
        self.verticalLayoutRight = QtWidgets.QVBoxLayout(self.widgetRight)
        self.verticalLayoutRight.setContentsMargins(6, 0, 0, 0)
        self.verticalLayoutRight.setObjectName("verticalLayoutRight")
        self.labelInfo = QtWidgets.QLabel(self.widgetRight)
        self.labelInfo.setObjectName("labelInfo")
        self.verticalLayoutRight.addWidget(self.labelInfo)
        self.plainTextEdit = QtWidgets.QPlainTextEdit(self.widgetRight)
        self.plainTextEdit.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOn)
        self.plainTextEdit.setReadOnly(True)
        self.plainTextEdit.setObjectName("plainTextEdit")
        self.verticalLayoutRight.addWidget(self.plainTextEdit)
        self.verticalLayout.addWidget(self.splitter)

        self.retranslateUi(FormLogIntegridade)
        QtCore.QMetaObject.connectSlotsByName(FormLogIntegridade)

    def retranslateUi(self, FormLogIntegridade):
        _translate = QtCore.QCoreApplication.translate
        FormLogIntegridade.setWindowTitle(_translate("FormLogIntegridade", "Logs de Verificação de Integridade"))
        self.labelDia.setText(_translate("FormLogIntegridade", "Data"))
        self.labelExecucao.setText(_translate("FormLogIntegridade", "Execuções"))
        self.labelInfo.setText(_translate("FormLogIntegridade", "Selecione uma data e horário para visualizar os logs."))
