# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'resources/form/integridade.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormVerificacaoIntegridade(object):
    def setupUi(self, FormVerificacaoIntegridade):
        FormVerificacaoIntegridade.setObjectName("FormVerificacaoIntegridade")
        self.verticalLayout = QtWidgets.QVBoxLayout(FormVerificacaoIntegridade)
        self.verticalLayout.setObjectName("verticalLayout")
        self.labelDescricao = QtWidgets.QLabel(FormVerificacaoIntegridade)
        self.labelDescricao.setObjectName("labelDescricao")
        self.verticalLayout.addWidget(self.labelDescricao)
        self.layoutParametros = QtWidgets.QHBoxLayout()
        self.layoutParametros.setObjectName("layoutParametros")
        self.labelDataInicio = QtWidgets.QLabel(FormVerificacaoIntegridade)
        self.labelDataInicio.setObjectName("labelDataInicio")
        self.layoutParametros.addWidget(self.labelDataInicio)
        self.dataInicio = QtWidgets.QDateEdit(FormVerificacaoIntegridade)
        self.dataInicio.setCalendarPopup(True)
        self.dataInicio.setObjectName("dataInicio")
        self.layoutParametros.addWidget(self.dataInicio)
        self.labelDataFim = QtWidgets.QLabel(FormVerificacaoIntegridade)
        self.labelDataFim.setObjectName("labelDataFim")
        self.layoutParametros.addWidget(self.labelDataFim)
        self.dataFim = QtWidgets.QDateEdit(FormVerificacaoIntegridade)
        self.dataFim.setCalendarPopup(True)
        self.dataFim.setObjectName("dataFim")
        self.layoutParametros.addWidget(self.dataFim)
        self.verticalLayout.addLayout(self.layoutParametros)
        self.layoutBotoes = QtWidgets.QHBoxLayout()
        self.layoutBotoes.setObjectName("layoutBotoes")
        self.btnVerificar = QtWidgets.QPushButton(FormVerificacaoIntegridade)
        self.btnVerificar.setObjectName("btnVerificar")
        self.layoutBotoes.addWidget(self.btnVerificar)
        self.btnCorrigir = QtWidgets.QPushButton(FormVerificacaoIntegridade)
        self.btnCorrigir.setObjectName("btnCorrigir")
        self.layoutBotoes.addWidget(self.btnCorrigir)
        self.btnFechar = QtWidgets.QPushButton(FormVerificacaoIntegridade)
        self.btnFechar.setObjectName("btnFechar")
        self.layoutBotoes.addWidget(self.btnFechar)
        self.verticalLayout.addLayout(self.layoutBotoes)
        self.tabelaDiferencas = QtWidgets.QTableWidget(FormVerificacaoIntegridade)
        self.tabelaDiferencas.setObjectName("tabelaDiferencas")
        self.tabelaDiferencas.setColumnCount(5)
        self.tabelaDiferencas.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tabelaDiferencas.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tabelaDiferencas.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tabelaDiferencas.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tabelaDiferencas.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tabelaDiferencas.setHorizontalHeaderItem(4, item)
        self.verticalLayout.addWidget(self.tabelaDiferencas)

        self.retranslateUi(FormVerificacaoIntegridade)
        QtCore.QMetaObject.connectSlotsByName(FormVerificacaoIntegridade)

    def retranslateUi(self, FormVerificacaoIntegridade):
        _translate = QtCore.QCoreApplication.translate
        FormVerificacaoIntegridade.setWindowTitle(_translate("FormVerificacaoIntegridade", "Verificação de Integridade"))
        self.labelDescricao.setText(_translate("FormVerificacaoIntegridade", "Compare os dados entre o ERP e a API e identifique inconsistências."))
        self.labelDataInicio.setText(_translate("FormVerificacaoIntegridade", "De:"))
        self.labelDataFim.setText(_translate("FormVerificacaoIntegridade", "Até:"))
        self.btnVerificar.setText(_translate("FormVerificacaoIntegridade", "🔎 Verificar"))
        self.btnCorrigir.setText(_translate("FormVerificacaoIntegridade", "🛠 Corrigir Diferenças"))
        self.btnFechar.setText(_translate("FormVerificacaoIntegridade", "Fechar"))
        item = self.tabelaDiferencas.horizontalHeaderItem(0)
        item.setText(_translate("FormVerificacaoIntegridade", "Entidade"))
        item = self.tabelaDiferencas.horizontalHeaderItem(1)
        item.setText(_translate("FormVerificacaoIntegridade", "ID"))
        item = self.tabelaDiferencas.horizontalHeaderItem(2)
        item.setText(_translate("FormVerificacaoIntegridade", "Campo"))
        item = self.tabelaDiferencas.horizontalHeaderItem(3)
        item.setText(_translate("FormVerificacaoIntegridade", "Valor ERP"))
        item = self.tabelaDiferencas.horizontalHeaderItem(4)
        item.setText(_translate("FormVerificacaoIntegridade", "Valor API"))

def show_form():
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormVerificacaoIntegridade = QtWidgets.QWidget()
    ui = Ui_FormVerificacaoIntegridade()
    ui.setupUi(FormVerificacaoIntegridade)
    FormVerificacaoIntegridade.show()
    sys.exit(app.exec_())

if __name__ == "__main__":
    show_form()

