# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'resources/form/configurada.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormIntegracaoConfigurada(object):
    def setupUi(self, FormIntegracaoConfigurada):
        FormIntegracaoConfigurada.setObjectName("FormIntegracaoConfigurada")
        FormIntegracaoConfigurada.resize(659, 533)
        FormIntegracaoConfigurada.setMinimumSize(QtCore.QSize(659, 533))
        FormIntegracaoConfigurada.setMaximumSize(QtCore.QSize(659, 533))
        self.verticalLayout = QtWidgets.QVBoxLayout(FormIntegracaoConfigurada)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayoutTopo = QtWidgets.QHBoxLayout()
        self.horizontalLayoutTopo.setSpacing(7)
        self.horizontalLayoutTopo.setObjectName("horizontalLayoutTopo")
        self.formLayout = QtWidgets.QFormLayout()
        self.formLayout.setObjectName("formLayout")
        self.labelTenant = QtWidgets.QLabel(FormIntegracaoConfigurada)
        self.labelTenant.setMinimumSize(QtCore.QSize(50, 0))
        self.labelTenant.setObjectName("labelTenant")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.labelTenant)
        self.labelTenantDesc = QtWidgets.QLabel(FormIntegracaoConfigurada)
        self.labelTenantDesc.setMinimumSize(QtCore.QSize(0, 0))
        self.labelTenantDesc.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.labelTenantDesc.setObjectName("labelTenantDesc")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.labelTenantDesc)
        self.horizontalLayoutTopo.addLayout(self.formLayout)
        self.formLayout_2 = QtWidgets.QFormLayout()
        self.formLayout_2.setObjectName("formLayout_2")
        self.labelAmbiente = QtWidgets.QLabel(FormIntegracaoConfigurada)
        self.labelAmbiente.setObjectName("labelAmbiente")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.labelAmbiente)
        self.labelAmbienteDesc = QtWidgets.QLabel(FormIntegracaoConfigurada)
        self.labelAmbienteDesc.setObjectName("labelAmbienteDesc")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.labelAmbienteDesc)
        self.horizontalLayoutTopo.addLayout(self.formLayout_2)
        self.verticalLayout.addLayout(self.horizontalLayoutTopo)
        self.groupGrupos = QtWidgets.QGroupBox(FormIntegracaoConfigurada)
        self.groupGrupos.setObjectName("groupGrupos")
        self.verticalLayoutGrupos = QtWidgets.QVBoxLayout(self.groupGrupos)
        self.verticalLayoutGrupos.setObjectName("verticalLayoutGrupos")
        self.tableGrupos = QtWidgets.QTableWidget(self.groupGrupos)
        self.tableGrupos.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectColumns)
        self.tableGrupos.setObjectName("tableGrupos")
        self.tableGrupos.setColumnCount(4)
        self.tableGrupos.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tableGrupos.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableGrupos.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableGrupos.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableGrupos.setHorizontalHeaderItem(3, item)
        self.verticalLayoutGrupos.addWidget(self.tableGrupos)
        self.verticalLayout.addWidget(self.groupGrupos)
        self.layoutOperacoes = QtWidgets.QVBoxLayout()
        self.layoutOperacoes.setObjectName("layoutOperacoes")
        self.btnCargaInicial = QtWidgets.QPushButton(FormIntegracaoConfigurada)
        self.btnCargaInicial.setObjectName("btnCargaInicial")
        self.layoutOperacoes.addWidget(self.btnCargaInicial)
        self.btnIntegracao = QtWidgets.QPushButton(FormIntegracaoConfigurada)
        self.btnIntegracao.setObjectName("btnIntegracao")
        self.layoutOperacoes.addWidget(self.btnIntegracao)
        self.btnVerificarIntegridade = QtWidgets.QPushButton(FormIntegracaoConfigurada)
        self.btnVerificarIntegridade.setObjectName("btnVerificarIntegridade")
        self.layoutOperacoes.addWidget(self.btnVerificarIntegridade)
        self.btnAgendarIntegracao = QtWidgets.QPushButton(FormIntegracaoConfigurada)
        self.btnAgendarIntegracao.setObjectName("btnAgendarIntegracao")
        self.layoutOperacoes.addWidget(self.btnAgendarIntegracao)
        self.btnHistoricoIntegracoes = QtWidgets.QPushButton(FormIntegracaoConfigurada)
        self.btnHistoricoIntegracoes.setObjectName("btnHistoricoIntegracoes")
        self.layoutOperacoes.addWidget(self.btnHistoricoIntegracoes)
        self.verticalLayout.addLayout(self.layoutOperacoes)
        self.horizontalLayoutBottom = QtWidgets.QHBoxLayout()
        self.horizontalLayoutBottom.setObjectName("horizontalLayoutBottom")
        self.btnAlterarConfiguracao = QtWidgets.QPushButton(FormIntegracaoConfigurada)
        self.btnAlterarConfiguracao.setObjectName("btnAlterarConfiguracao")
        self.horizontalLayoutBottom.addWidget(self.btnAlterarConfiguracao)
        self.btnDesativar = QtWidgets.QPushButton(FormIntegracaoConfigurada)
        self.btnDesativar.setObjectName("btnDesativar")
        self.horizontalLayoutBottom.addWidget(self.btnDesativar)
        self.verticalLayout.addLayout(self.horizontalLayoutBottom)

        self.retranslateUi(FormIntegracaoConfigurada)
        QtCore.QMetaObject.connectSlotsByName(FormIntegracaoConfigurada)

    def retranslateUi(self, FormIntegracaoConfigurada):
        _translate = QtCore.QCoreApplication.translate
        FormIntegracaoConfigurada.setWindowTitle(_translate("FormIntegracaoConfigurada", "Integração por APIs"))
        self.labelTenant.setText(_translate("FormIntegracaoConfigurada", "Tenant: "))
        self.labelTenantDesc.setText(_translate("FormIntegracaoConfigurada", "<html><head/><body><p><span style=\" font-weight:600; color:#3d3846;\">47</span></p></body></html>"))
        self.labelAmbiente.setText(_translate("FormIntegracaoConfigurada", "Ambiente:"))
        self.labelAmbienteDesc.setText(_translate("FormIntegracaoConfigurada", "<html><head/><body><p><span style=\" font-weight:600; color:#1a5fb4;\">??</span></p></body></html>"))
        self.groupGrupos.setTitle(_translate("FormIntegracaoConfigurada", "Grupos Empresariais"))
        item = self.tableGrupos.horizontalHeaderItem(0)
        item.setText(_translate("FormIntegracaoConfigurada", "id"))
        item = self.tableGrupos.horizontalHeaderItem(1)
        item.setText(_translate("FormIntegracaoConfigurada", "Código"))
        item = self.tableGrupos.horizontalHeaderItem(2)
        item.setText(_translate("FormIntegracaoConfigurada", "Nome"))
        item = self.tableGrupos.horizontalHeaderItem(3)
        item.setText(_translate("FormIntegracaoConfigurada", "Habilitado"))
        self.btnCargaInicial.setText(_translate("FormIntegracaoConfigurada", "⚡ Carga Inicial"))
        self.btnIntegracao.setText(_translate("FormIntegracaoConfigurada", "⚡ Integração"))
        self.btnVerificarIntegridade.setText(_translate("FormIntegracaoConfigurada", "🔍 Verificar Integridade"))
        self.btnAgendarIntegracao.setText(_translate("FormIntegracaoConfigurada", "⏱ Agendamento Integração"))
        self.btnHistoricoIntegracoes.setText(_translate("FormIntegracaoConfigurada", "📈 Histórico de Integrações"))
        self.btnAlterarConfiguracao.setText(_translate("FormIntegracaoConfigurada", "⚙ Alterar Configuração"))
        self.btnDesativar.setText(_translate("FormIntegracaoConfigurada", "❌ Desativar Integração"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormIntegracaoConfigurada = QtWidgets.QWidget()
    ui = Ui_FormIntegracaoConfigurada()
    ui.setupUi(FormIntegracaoConfigurada)
    FormIntegracaoConfigurada.show()
    sys.exit(app.exec_())
