# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'resources/form/ativacao.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormIntegracaoNaoConfigurada(object):
    def setupUi(self, FormIntegracaoNaoConfigurada):
        FormIntegracaoNaoConfigurada.setObjectName("FormIntegracaoNaoConfigurada")
        FormIntegracaoNaoConfigurada.resize(667, 467)
        FormIntegracaoNaoConfigurada.setMinimumSize(QtCore.QSize(667, 467))
        FormIntegracaoNaoConfigurada.setMaximumSize(QtCore.QSize(667, 467))
        self.verticalLayout = QtWidgets.QVBoxLayout(FormIntegracaoNaoConfigurada)
        self.verticalLayout.setObjectName("verticalLayout")
        self.labelInfo = QtWidgets.QLabel(FormIntegracaoNaoConfigurada)
        self.labelInfo.setObjectName("labelInfo")
        self.verticalLayout.addWidget(self.labelInfo)
        self.editChaveAtivacao = QtWidgets.QLineEdit(FormIntegracaoNaoConfigurada)
        self.editChaveAtivacao.setCursorPosition(0)
        self.editChaveAtivacao.setClearButtonEnabled(True)
        self.editChaveAtivacao.setObjectName("editChaveAtivacao")
        self.verticalLayout.addWidget(self.editChaveAtivacao)
        self.groupEmpresarial = QtWidgets.QGroupBox(FormIntegracaoNaoConfigurada)
        self.groupEmpresarial.setObjectName("groupEmpresarial")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupEmpresarial)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.tableGrupos = QtWidgets.QTableWidget(self.groupEmpresarial)
        self.tableGrupos.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectColumns)
        self.tableGrupos.setObjectName("tableGrupos")
        self.tableGrupos.setColumnCount(4)
        self.tableGrupos.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tableGrupos.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableGrupos.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableGrupos.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableGrupos.setHorizontalHeaderItem(3, item)
        self.verticalLayout_2.addWidget(self.tableGrupos)
        self.verticalLayout.addWidget(self.groupEmpresarial)
        self.horizontalLayoutButtons = QtWidgets.QHBoxLayout()
        self.horizontalLayoutButtons.setObjectName("horizontalLayoutButtons")
        self.btnAtivar = QtWidgets.QPushButton(FormIntegracaoNaoConfigurada)
        self.btnAtivar.setObjectName("btnAtivar")
        self.horizontalLayoutButtons.addWidget(self.btnAtivar)
        self.btnCancelar = QtWidgets.QPushButton(FormIntegracaoNaoConfigurada)
        self.btnCancelar.setObjectName("btnCancelar")
        self.horizontalLayoutButtons.addWidget(self.btnCancelar)
        self.verticalLayout.addLayout(self.horizontalLayoutButtons)

        self.retranslateUi(FormIntegracaoNaoConfigurada)
        QtCore.QMetaObject.connectSlotsByName(FormIntegracaoNaoConfigurada)

    def retranslateUi(self, FormIntegracaoNaoConfigurada):
        _translate = QtCore.QCoreApplication.translate
        FormIntegracaoNaoConfigurada.setWindowTitle(_translate("FormIntegracaoNaoConfigurada", "Integração por APIs"))
        self.labelInfo.setText(_translate("FormIntegracaoNaoConfigurada", "Digite a Chave de ativação,  (ex: AUS5-DIKI-D576-DYUL)"))
        self.editChaveAtivacao.setInputMask(_translate("FormIntegracaoNaoConfigurada", ">NNNN-NNNN-NNNN-NNNN;_"))
        self.editChaveAtivacao.setText(_translate("FormIntegracaoNaoConfigurada", "---"))
        self.editChaveAtivacao.setPlaceholderText(_translate("FormIntegracaoNaoConfigurada", "Chave de ativação (ex: AUS5-DIKI-D576-DYUL)"))
        self.groupEmpresarial.setTitle(_translate("FormIntegracaoNaoConfigurada", "Grupos Empresariais"))
        item = self.tableGrupos.horizontalHeaderItem(0)
        item.setText(_translate("FormIntegracaoNaoConfigurada", "id"))
        item = self.tableGrupos.horizontalHeaderItem(1)
        item.setText(_translate("FormIntegracaoNaoConfigurada", "Código"))
        item = self.tableGrupos.horizontalHeaderItem(2)
        item.setText(_translate("FormIntegracaoNaoConfigurada", "Nome"))
        item = self.tableGrupos.horizontalHeaderItem(3)
        item.setText(_translate("FormIntegracaoNaoConfigurada", "Habilitado"))
        self.btnAtivar.setText(_translate("FormIntegracaoNaoConfigurada", "Ativar Integração"))
        self.btnCancelar.setText(_translate("FormIntegracaoNaoConfigurada", "Cancelar"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormIntegracaoNaoConfigurada = QtWidgets.QWidget()
    ui = Ui_FormIntegracaoNaoConfigurada()
    ui.setupUi(FormIntegracaoNaoConfigurada)
    FormIntegracaoNaoConfigurada.show()
    sys.exit(app.exec_())
