# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'resources/form/browser_execucoes.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_BrowserExecucoes(object):
    def setupUi(self, BrowserExecucoes):
        BrowserExecucoes.setObjectName("BrowserExecucoes")
        BrowserExecucoes.resize(1052, 533)
        self.verticalLayout = QtWidgets.QVBoxLayout(BrowserExecucoes)
        self.verticalLayout.setContentsMargins(2, 2, 2, 2)
        self.verticalLayout.setSpacing(2)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(BrowserExecucoes)
        self.groupBox.setEnabled(True)
        self.groupBox.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.groupBox.setStyleSheet("")
        self.groupBox.setTitle("")
        self.groupBox.setFlat(True)
        self.groupBox.setCheckable(False)
        self.groupBox.setObjectName("groupBox")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.groupBox)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setSpacing(2)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem = QtWidgets.QSpacerItem(966, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.btnSair = QtWidgets.QToolButton(self.groupBox)
        self.btnSair.setStyleSheet("")
        self.btnSair.setToolButtonStyle(QtCore.Qt.ToolButtonTextBesideIcon)
        self.btnSair.setAutoRaise(True)
        self.btnSair.setObjectName("btnSair")
        self.horizontalLayout_2.addWidget(self.btnSair)
        self.verticalLayout.addWidget(self.groupBox)
        self.tableDados = QtWidgets.QTableWidget(BrowserExecucoes)
        self.tableDados.setAutoFillBackground(False)
        self.tableDados.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectColumns)
        self.tableDados.setObjectName("tableDados")
        self.tableDados.setColumnCount(12)
        self.tableDados.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tableDados.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableDados.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableDados.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableDados.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableDados.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableDados.setHorizontalHeaderItem(5, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableDados.setHorizontalHeaderItem(6, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableDados.setHorizontalHeaderItem(7, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableDados.setHorizontalHeaderItem(8, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableDados.setHorizontalHeaderItem(9, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableDados.setHorizontalHeaderItem(10, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableDados.setHorizontalHeaderItem(11, item)
        self.verticalLayout.addWidget(self.tableDados)

        self.retranslateUi(BrowserExecucoes)
        self.btnSair.clicked.connect(BrowserExecucoes.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(BrowserExecucoes)

    def retranslateUi(self, BrowserExecucoes):
        _translate = QtCore.QCoreApplication.translate
        BrowserExecucoes.setWindowTitle(_translate("BrowserExecucoes", "Integração por APIs"))
        self.btnSair.setText(_translate("BrowserExecucoes", "✖ &Sair"))
        item = self.tableDados.horizontalHeaderItem(0)
        item.setText(_translate("BrowserExecucoes", "jobtype"))
        item = self.tableDados.horizontalHeaderItem(1)
        item.setText(_translate("BrowserExecucoes", "job"))
        item = self.tableDados.horizontalHeaderItem(2)
        item.setText(_translate("BrowserExecucoes", "Código"))
        item = self.tableDados.horizontalHeaderItem(3)
        item.setText(_translate("BrowserExecucoes", "Descrição"))
        item = self.tableDados.horizontalHeaderItem(4)
        item.setText(_translate("BrowserExecucoes", "Entrada"))
        item = self.tableDados.horizontalHeaderItem(5)
        item.setText(_translate("BrowserExecucoes", "Saída"))
        item = self.tableDados.horizontalHeaderItem(6)
        item.setText(_translate("BrowserExecucoes", "Status"))
        item = self.tableDados.horizontalHeaderItem(7)
        item.setText(_translate("BrowserExecucoes", "Progresso"))
        item = self.tableDados.horizontalHeaderItem(8)
        item.setText(_translate("BrowserExecucoes", "Enfileiramento"))
        item = self.tableDados.horizontalHeaderItem(9)
        item.setText(_translate("BrowserExecucoes", "Início Execução"))
        item = self.tableDados.horizontalHeaderItem(10)
        item.setText(_translate("BrowserExecucoes", "Fim Execução"))
        item = self.tableDados.horizontalHeaderItem(11)
        item.setText(_translate("BrowserExecucoes", "Duração"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    BrowserExecucoes = QtWidgets.QDialog()
    ui = Ui_BrowserExecucoes()
    ui.setupUi(BrowserExecucoes)
    BrowserExecucoes.show()
    sys.exit(app.exec_())
