# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'resources/form/browser_execucoes_detail.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_BrowserDetalhes(object):
    def setupUi(self, BrowserDetalhes):
        BrowserDetalhes.setObjectName("BrowserDetalhes")
        BrowserDetalhes.resize(1057, 590)
        self.verticalLayout = QtWidgets.QVBoxLayout(BrowserDetalhes)
        self.verticalLayout.setObjectName("verticalLayout")
        self.plainTextEdit = QtWidgets.QPlainTextEdit(BrowserDetalhes)
        self.plainTextEdit.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOn)
        self.plainTextEdit.setReadOnly(True)
        self.plainTextEdit.setObjectName("plainTextEdit")
        self.verticalLayout.addWidget(self.plainTextEdit)

        self.retranslateUi(BrowserDetalhes)
        QtCore.QMetaObject.connectSlotsByName(BrowserDetalhes)

    def retranslateUi(self, BrowserDetalhes):
        _translate = QtCore.QCoreApplication.translate
        BrowserDetalhes.setWindowTitle(_translate("BrowserDetalhes", "Detalhes da execução"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    BrowserDetalhes = QtWidgets.QWidget()
    ui = Ui_BrowserDetalhes()
    ui.setupUi(BrowserDetalhes)
    BrowserDetalhes.show()
    sys.exit(app.exec_())
