# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'resources/form_v2/config_inicial.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_ConfigInicial(object):
    def setupUi(self, ConfigInicial):
        ConfigInicial.setObjectName("ConfigInicial")
        ConfigInicial.resize(600, 450)
        self.verticalLayout = QtWidgets.QVBoxLayout(ConfigInicial)
        self.verticalLayout.setObjectName("verticalLayout")
        self.labelStatus = QtWidgets.QLabel(ConfigInicial)
        self.labelStatus.setObjectName("labelStatus")
        self.verticalLayout.addWidget(self.labelStatus)
        self.labelChave = QtWidgets.QLabel(ConfigInicial)
        self.labelChave.setObjectName("labelChave")
        self.verticalLayout.addWidget(self.labelChave)
        self.lineEditChave = QtWidgets.QLineEdit(ConfigInicial)
        self.lineEditChave.setObjectName("lineEditChave")
        self.verticalLayout.addWidget(self.lineEditChave)
        self.labelGrupos = QtWidgets.QLabel(ConfigInicial)
        self.labelGrupos.setObjectName("labelGrupos")
        self.verticalLayout.addWidget(self.labelGrupos)
        self.scrollArea = QtWidgets.QScrollArea(ConfigInicial)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.checkBoxGrupoA = QtWidgets.QCheckBox(self.scrollAreaWidgetContents)
        self.checkBoxGrupoA.setObjectName("checkBoxGrupoA")
        self.verticalLayout_2.addWidget(self.checkBoxGrupoA)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.verticalLayout.addWidget(self.scrollArea)
        self.btnValidar = QtWidgets.QPushButton(ConfigInicial)
        self.btnValidar.setObjectName("btnValidar")
        self.verticalLayout.addWidget(self.btnValidar)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.btnCancelar = QtWidgets.QPushButton(ConfigInicial)
        self.btnCancelar.setObjectName("btnCancelar")
        self.horizontalLayout.addWidget(self.btnCancelar)
        self.btnSalvar = QtWidgets.QPushButton(ConfigInicial)
        self.btnSalvar.setObjectName("btnSalvar")
        self.horizontalLayout.addWidget(self.btnSalvar)
        self.verticalLayout.addLayout(self.horizontalLayout)

        self.retranslateUi(ConfigInicial)
        QtCore.QMetaObject.connectSlotsByName(ConfigInicial)

    def retranslateUi(self, ConfigInicial):
        _translate = QtCore.QCoreApplication.translate
        ConfigInicial.setWindowTitle(_translate("ConfigInicial", "Configuração da Integração por APIs"))
        self.labelStatus.setText(_translate("ConfigInicial", "STATUS: Integração não configurada"))
        self.labelChave.setText(_translate("ConfigInicial", "Chave de Ativação:"))
        self.lineEditChave.setPlaceholderText(_translate("ConfigInicial", "AAAA-BBBB-CCCC-DDDD"))
        self.labelGrupos.setText(_translate("ConfigInicial", "Grupos Empresariais Disponíveis:"))
        self.checkBoxGrupoA.setText(_translate("ConfigInicial", "Grupo A - Matriz"))
        self.btnValidar.setText(_translate("ConfigInicial", "Validar Chave"))
        self.btnCancelar.setText(_translate("ConfigInicial", "Cancelar"))
        self.btnSalvar.setText(_translate("ConfigInicial", "Salvar Configuração"))

def show_form():
    import sys
    app = QtWidgets.QApplication(sys.argv)
    ConfigInicial = QtWidgets.QDialog()
    ui = Ui_ConfigInicial()
    ui.setupUi(ConfigInicial)
    ConfigInicial.show()
    sys.exit(app.exec_())

if __name__ == "__main__":
    show_form()

