# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'resources/form/pendencias_detalhes.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormItensPendentesDetalhes(object):
    def setupUi(self, FormItensPendentesDetalhes):
        FormItensPendentesDetalhes.setObjectName("FormItensPendentesDetalhes")
        FormItensPendentesDetalhes.resize(1024, 768)
        FormItensPendentesDetalhes.setMinimumSize(QtCore.QSize(1024, 768))
        FormItensPendentesDetalhes.setMaximumSize(QtCore.QSize(1024, 768))
        self.verticalLayout = QtWidgets.QVBoxLayout(FormItensPendentesDetalhes)
        self.verticalLayout.setObjectName("verticalLayout")
        self.label = QtWidgets.QLabel(FormItensPendentesDetalhes)
        self.label.setStyleSheet("font-size: 16px; font-weight: bold; margin: 4px;")
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        self.edtFiltro = QtWidgets.QLineEdit(FormItensPendentesDetalhes)
        self.edtFiltro.setClearButtonEnabled(True)
        self.edtFiltro.setObjectName("edtFiltro")
        self.verticalLayout.addWidget(self.edtFiltro)
        self.groupItensDetalhes = QtWidgets.QGroupBox(FormItensPendentesDetalhes)
        self.groupItensDetalhes.setTitle("")
        self.groupItensDetalhes.setObjectName("groupItensDetalhes")
        self.verticalLayoutGrupos = QtWidgets.QVBoxLayout(self.groupItensDetalhes)
        self.verticalLayoutGrupos.setObjectName("verticalLayoutGrupos")
        self.tableItensDetalhes = QtWidgets.QTableWidget(self.groupItensDetalhes)
        self.tableItensDetalhes.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectColumns)
        self.tableItensDetalhes.setCornerButtonEnabled(False)
        self.tableItensDetalhes.setObjectName("tableItensDetalhes")
        self.tableItensDetalhes.setColumnCount(2)
        self.tableItensDetalhes.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tableItensDetalhes.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableItensDetalhes.setHorizontalHeaderItem(1, item)
        self.verticalLayoutGrupos.addWidget(self.tableItensDetalhes)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.btn_prev = QtWidgets.QPushButton(self.groupItensDetalhes)
        self.btn_prev.setObjectName("btn_prev")
        self.horizontalLayout.addWidget(self.btn_prev)
        self.lbl_page = QtWidgets.QLabel(self.groupItensDetalhes)
        self.lbl_page.setObjectName("lbl_page")
        self.horizontalLayout.addWidget(self.lbl_page)
        self.btn_next = QtWidgets.QPushButton(self.groupItensDetalhes)
        self.btn_next.setObjectName("btn_next")
        self.horizontalLayout.addWidget(self.btn_next)
        self.verticalLayoutGrupos.addLayout(self.horizontalLayout)
        self.verticalLayout.addWidget(self.groupItensDetalhes)

        self.retranslateUi(FormItensPendentesDetalhes)
        QtCore.QMetaObject.connectSlotsByName(FormItensPendentesDetalhes)

    def retranslateUi(self, FormItensPendentesDetalhes):
        _translate = QtCore.QCoreApplication.translate
        FormItensPendentesDetalhes.setWindowTitle(_translate("FormItensPendentesDetalhes", "Integração por APIs"))
        self.label.setText(_translate("FormItensPendentesDetalhes", "<Entidade>"))
        self.edtFiltro.setPlaceholderText(_translate("FormItensPendentesDetalhes", "Digite para filtrar...\""))
        item = self.tableItensDetalhes.horizontalHeaderItem(0)
        item.setText(_translate("FormItensPendentesDetalhes", "ID"))
        item = self.tableItensDetalhes.horizontalHeaderItem(1)
        item.setText(_translate("FormItensPendentesDetalhes", "Dados"))
        self.btn_prev.setText(_translate("FormItensPendentesDetalhes", "⬅ Anterior"))
        self.lbl_page.setText(_translate("FormItensPendentesDetalhes", "Página 0 de 0"))
        self.btn_next.setText(_translate("FormItensPendentesDetalhes", "Próximo ➡"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormItensPendentesDetalhes = QtWidgets.QWidget()
    ui = Ui_FormItensPendentesDetalhes()
    ui.setupUi(FormItensPendentesDetalhes)
    FormItensPendentesDetalhes.show()
    sys.exit(app.exec_())
