# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'resources/form/verificacao_integridade.ui'
#
# Created by: PyQt5 UI code generator 5.15.6
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormVerificacaoIntegridade(object):
    def setupUi(self, FormVerificacaoIntegridade):
        FormVerificacaoIntegridade.setObjectName("FormVerificacaoIntegridade")
        FormVerificacaoIntegridade.resize(360, 378)
        self.verticalLayout = QtWidgets.QVBoxLayout(FormVerificacaoIntegridade)
        self.verticalLayout.setObjectName("verticalLayout")
        self.labelDescricao = QtWidgets.QLabel(FormVerificacaoIntegridade)
        self.labelDescricao.setWordWrap(True)
        self.labelDescricao.setObjectName("labelDescricao")
        self.verticalLayout.addWidget(self.labelDescricao)
        self.groupBox = QtWidgets.QGroupBox(FormVerificacaoIntegridade)
        self.groupBox.setTitle("")
        self.groupBox.setFlat(False)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.checkTraceback = QtWidgets.QCheckBox(self.groupBox)
        self.checkTraceback.setObjectName("checkTraceback")
        self.verticalLayout_2.addWidget(self.checkTraceback)
        self.checkVerboso = QtWidgets.QCheckBox(self.groupBox)
        self.checkVerboso.setObjectName("checkVerboso")
        self.verticalLayout_2.addWidget(self.checkVerboso)
        self.checkDataNoLog = QtWidgets.QCheckBox(self.groupBox)
        self.checkDataNoLog.setObjectName("checkDataNoLog")
        self.verticalLayout_2.addWidget(self.checkDataNoLog)
        self.checkPararCasoDif = QtWidgets.QCheckBox(self.groupBox)
        self.checkPararCasoDif.setObjectName("checkPararCasoDif")
        self.verticalLayout_2.addWidget(self.checkPararCasoDif)
        self.checkDetalharDiff = QtWidgets.QCheckBox(self.groupBox)
        self.checkDetalharDiff.setObjectName("checkDetalharDiff")
        self.verticalLayout_2.addWidget(self.checkDetalharDiff)
        self.checkCorrigir = QtWidgets.QCheckBox(self.groupBox)
        self.checkCorrigir.setObjectName("checkCorrigir")
        self.verticalLayout_2.addWidget(self.checkCorrigir)
        self.formLayout = QtWidgets.QFormLayout()
        self.formLayout.setObjectName("formLayout")
        self.labelTipoVerificacao = QtWidgets.QLabel(self.groupBox)
        self.labelTipoVerificacao.setObjectName("labelTipoVerificacao")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.labelTipoVerificacao)
        self.cmbTpVerificacao = QtWidgets.QComboBox(self.groupBox)
        self.cmbTpVerificacao.setObjectName("cmbTpVerificacao")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.cmbTpVerificacao)
        self.verticalLayout_2.addLayout(self.formLayout)
        self.verticalLayout.addWidget(self.groupBox)
        self.buttonExecutar = QtWidgets.QPushButton(FormVerificacaoIntegridade)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.buttonExecutar.sizePolicy().hasHeightForWidth())
        self.buttonExecutar.setSizePolicy(sizePolicy)
        self.buttonExecutar.setObjectName("buttonExecutar")
        self.verticalLayout.addWidget(self.buttonExecutar)
        self.buttonExecutarRapida = QtWidgets.QPushButton(FormVerificacaoIntegridade)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.buttonExecutarRapida.sizePolicy().hasHeightForWidth())
        self.buttonExecutarRapida.setSizePolicy(sizePolicy)
        self.buttonExecutarRapida.setObjectName("buttonExecutarRapida")
        self.verticalLayout.addWidget(self.buttonExecutarRapida)
        self.buttonVerLogs = QtWidgets.QPushButton(FormVerificacaoIntegridade)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.buttonVerLogs.sizePolicy().hasHeightForWidth())
        self.buttonVerLogs.setSizePolicy(sizePolicy)
        self.buttonVerLogs.setEnabled(False)
        self.buttonVerLogs.setObjectName("buttonVerLogs")
        self.verticalLayout.addWidget(self.buttonVerLogs)

        self.retranslateUi(FormVerificacaoIntegridade)
        QtCore.QMetaObject.connectSlotsByName(FormVerificacaoIntegridade)

    def retranslateUi(self, FormVerificacaoIntegridade):
        _translate = QtCore.QCoreApplication.translate
        FormVerificacaoIntegridade.setWindowTitle(_translate("FormVerificacaoIntegridade", "Verificação de integridade"))
        self.labelDescricao.setText(_translate("FormVerificacaoIntegridade", "Compare os dados entre o ERP e a API e identifique inconsistências."))
        self.checkTraceback.setText(_translate("FormVerificacaoIntegridade", "Exibir trace."))
        self.checkVerboso.setText(_translate("FormVerificacaoIntegridade", "Log verboso."))
        self.checkDataNoLog.setText(_translate("FormVerificacaoIntegridade", "Imprimir data no log."))
        self.checkPararCasoDif.setText(_translate("FormVerificacaoIntegridade", "Parar caso encontre diferenças."))
        self.checkDetalharDiff.setText(_translate("FormVerificacaoIntegridade", "Detalhar diferenças."))
        self.checkCorrigir.setText(_translate("FormVerificacaoIntegridade", "Corrigir diferenças encontradas."))
        self.labelTipoVerificacao.setText(_translate("FormVerificacaoIntegridade", "Tipo verificação: "))
        self.buttonExecutar.setText(_translate("FormVerificacaoIntegridade", "▶   Executar Verificação Completa"))
        self.buttonExecutarRapida.setText(_translate("FormVerificacaoIntegridade", "⚡   Executar Verificação Rápida"))
        self.buttonVerLogs.setText(_translate("FormVerificacaoIntegridade", "📄   Visualizar Logs"))
