# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'resources/form_v2/painel_controle.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_PainelControle(object):
    def setupUi(self, PainelControle):
        PainelControle.setObjectName("PainelControle")
        PainelControle.resize(700, 500)
        self.verticalLayout = QtWidgets.QVBoxLayout(PainelControle)
        self.verticalLayout.setObjectName("verticalLayout")
        self.labelStatus = QtWidgets.QLabel(PainelControle)
        self.labelStatus.setObjectName("labelStatus")
        self.verticalLayout.addWidget(self.labelStatus)
        self.labelTenant = QtWidgets.QLabel(PainelControle)
        self.labelTenant.setObjectName("labelTenant")
        self.verticalLayout.addWidget(self.labelTenant)
        self.labelUltimaSinc = QtWidgets.QLabel(PainelControle)
        self.labelUltimaSinc.setObjectName("labelUltimaSinc")
        self.verticalLayout.addWidget(self.labelUltimaSinc)
        self.labelGrupos = QtWidgets.QLabel(PainelControle)
        self.labelGrupos.setObjectName("labelGrupos")
        self.verticalLayout.addWidget(self.labelGrupos)
        self.textEditGrupos = QtWidgets.QTextEdit(PainelControle)
        self.textEditGrupos.setObjectName("textEditGrupos")
        self.verticalLayout.addWidget(self.textEditGrupos)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.btnCargaInicial = QtWidgets.QPushButton(PainelControle)
        self.btnCargaInicial.setObjectName("btnCargaInicial")
        self.horizontalLayout.addWidget(self.btnCargaInicial)
        self.btnCargaContinua = QtWidgets.QPushButton(PainelControle)
        self.btnCargaContinua.setObjectName("btnCargaContinua")
        self.horizontalLayout.addWidget(self.btnCargaContinua)
        self.btnVerificar = QtWidgets.QPushButton(PainelControle)
        self.btnVerificar.setObjectName("btnVerificar")
        self.horizontalLayout.addWidget(self.btnVerificar)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.btnDesativar = QtWidgets.QPushButton(PainelControle)
        self.btnDesativar.setObjectName("btnDesativar")
        self.verticalLayout.addWidget(self.btnDesativar)

        self.retranslateUi(PainelControle)
        QtCore.QMetaObject.connectSlotsByName(PainelControle)

    def retranslateUi(self, PainelControle):
        _translate = QtCore.QCoreApplication.translate
        PainelControle.setWindowTitle(_translate("PainelControle", "Painel de Integração por APIs"))
        self.labelStatus.setText(_translate("PainelControle", "STATUS: Integração ativa"))
        self.labelTenant.setText(_translate("PainelControle", "Tenant Configurado: COMPANHIA_BRASILEIRA_123"))
        self.labelUltimaSinc.setText(_translate("PainelControle", "Última Sincronização: 15/04/2023 14:30 (há 2 dias)"))
        self.labelGrupos.setText(_translate("PainelControle", "Grupos Integrados:"))
        self.textEditGrupos.setPlainText(_translate("PainelControle", "- Grupo A - Matriz\n"
"- Grupo B - Filial São Paulo\n"
"- Grupo E - Filial Bahia"))
        self.btnCargaInicial.setText(_translate("PainelControle", "Carga Inicial"))
        self.btnCargaContinua.setText(_translate("PainelControle", "Carga Contínua"))
        self.btnVerificar.setText(_translate("PainelControle", "Verificar Integridade"))
        self.btnDesativar.setText(_translate("PainelControle", "Desativar Integração"))


def show_form():
    import sys
    app = QtWidgets.QApplication(sys.argv)
    PainelControle = QtWidgets.QDialog()
    ui = Ui_PainelControle()
    ui.setupUi(PainelControle)
    PainelControle.show()
    sys.exit(app.exec_())

if __name__ == "__main__":
    show_form()
