# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'resources/form/acompanhamento.ui'
#
# Created by: PyQt5 UI code generator 5.15.6
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormAcompanhamento(object):
    def setupUi(self, FormAcompanhamento):
        FormAcompanhamento.setObjectName("FormAcompanhamento")
        FormAcompanhamento.resize(1024, 540)
        self.verticalLayout = QtWidgets.QVBoxLayout(FormAcompanhamento)
        self.verticalLayout.setObjectName("verticalLayout")
        self.labelInfo = QtWidgets.QLabel(FormAcompanhamento)
        self.labelInfo.setObjectName("labelInfo")
        self.verticalLayout.addWidget(self.labelInfo)
        self.plainTextEdit = QtWidgets.QPlainTextEdit(FormAcompanhamento)
        self.plainTextEdit.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOn)
        self.plainTextEdit.setReadOnly(True)
        self.plainTextEdit.setObjectName("plainTextEdit")
        self.verticalLayout.addWidget(self.plainTextEdit)

        self.retranslateUi(FormAcompanhamento)
        QtCore.QMetaObject.connectSlotsByName(FormAcompanhamento)

    def retranslateUi(self, FormAcompanhamento):
        _translate = QtCore.QCoreApplication.translate
        FormAcompanhamento.setWindowTitle(_translate("FormAcompanhamento", "Acompanhamento de Execuções"))
        self.labelInfo.setText(_translate("FormAcompanhamento", "Visualize o andamento e os resultados das execuções de integração."))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormAcompanhamento = QtWidgets.QWidget()
    ui = Ui_FormAcompanhamento()
    ui.setupUi(FormAcompanhamento)
    FormAcompanhamento.show()
    sys.exit(app.exec_())
